@@ -33,21 +33,24 @@ def load_elastic_parameters(partner1: Particle, partner2: Particle) -> np.ndarra
     Returns
     -------
     np.ndarray
+
         An array, which contains the following quantities:
             0. The collision-reduced mass :math:`m_{cd}`
             #. The collision diameter :math:`\\sigma_{cd}`
-            #. The Lennard-Jones epsilon parameter :math:`\\varepsilon_{cd}`
-            #. The :math:`\\phi_{0}` parameter for the IPL potential, divided by the Boltzmann constant
-               (i.e. expressed as a temperature)
+            #. The Lennard-Jones epsilon parameter :math:`\\varepsilon_{cd}`, divided by Boltzmann's constant
+            #. The :math:`\\phi_{0}` parameter for the IPL potential, divided by Boltzmann's constant
             #. The :math:`\\beta` parameter for the IPL potential
             #. The :math:`C` parameter for the VSS model for the :math:`\\Omega^{(1,1)}` integral
-            #. The :math:`\omega` parameter for the VSS model for the :math:`\\Omega^{(1,1)}` integral
+            #. The :math:`\\omega` parameter for the VSS model for the :math:`\\Omega^{(1,1)}` integral
             #. The :math:`C` parameter for the VSS model for the :math:`\\Omega^{(2,2)}` integral
-            #. The :math:`\omega` parameter for the VSS model for the :math:`\\Omega^{(2,2)}` integral
+            #. The :math:`\\omega` parameter for the VSS model for the :math:`\\Omega^{(2,2)}` integral
             #. The :math:`C` parameter for the VSS model for the :math:`\\Omega_{tot}` integral
-            #. The :math:`\omega` parameter for the VSS model for the :math:`\\Omega_{tot}` integral
+            #. The :math:`\\omega` parameter for the VSS model for the :math:`\\Omega_{tot}` integral
             #. The :math:`C` parameter for the VSS model for the deflection angle
-            #. The :math:`\omega` parameter for the VSS model for the deflection angle
+            #. The :math:`\\omega` parameter for the VSS model for the deflection angle
+            #. The :math:`\\beta` parameter for the ESA model
+            #. The :math:`\\varepsilon_{0}` parameter for the ESA model
+            #. The :math:`r_{e}` parameter for the ESA model
 
     Notes
     -----
@@ -59,18 +62,21 @@ def load_elastic_parameters(partner1: Particle, partner2: Particle) -> np.ndarra
     eps = np.sqrt(partner1.LJe * partner2.LJe * ((partner1.LJs * partner2.LJs) ** 6)) / (sigma ** 6)
     this_dir, this_filename = split(__file__)
     csv_file_object = reader(open(join(this_dir, normcase('data/models/interactions.csv')), 'r'))
-    csv_file_object.next()
-    res = np.zeros(13)
+    next(csv_file_object)
+    res = np.zeros(16)
     res[:3] = [m, sigma, eps]
 
     for row in csv_file_object:
         if (row[0] == partner1.name and row[1] == partner2.name) or\
                 (row[1] == partner1.name and row[0] == partner2.name):
             rd = np.array(row[2:]).astype(np.float64)
-            res[3:] = [rd[0], rd[1], rd[2], rd[3], rd[4], rd[5], rd[6], rd[7], rd[8], rd[9]]
+            # res[3:] = [rd[0], rd[1], rd[2], rd[3], rd[4], rd[5], rd[6], rd[7], rd[8], rd[9]]
+            res[3:] = rd[:]
 
     res[3] *= constants.physical_constants['electron volt'][0] / constants.k
     res[4] *= 1.0 / constants.physical_constants['Angstrom star'][0]
+    res[14] *= constants.physical_constants['electron volt'][0] / 1000.0
+    res[15] *= constants.physical_constants['Angstrom star'][0]
     return res
 
 
@@ -100,7 +106,7 @@ def load_dissociation_parameters(molecule_name: str, partner_name: str) -> np.nd
     """
     this_dir, this_filename = split(__file__)
     csv_file_object = reader(open(join(this_dir, normcase('data/models/dissociation.csv')), 'r'))
-    csv_file_object.next()
+    next(csv_file_object)
     found = False
     for row in csv_file_object:
         if row[0] == molecule_name and row[1] == partner_name:
