@@ -405,10 +405,10 @@ def omega_esa(T: float, l: int, r: int, beta: float, eps: float) -> float:
     for i in range(7):
         a[i] = np.dot(coeff_array[i, :], beta_pow_array)
 
-    dimless_omega = (a[0] + a[1] * x) * np.exp(x - a[2] / a[3]) \
-                                      / (np.exp(x - a[2] / a[3]) + np.exp((a[2] - x) / a[3]))\
-                    + a[4] * np.exp(x - a[5] / a[6]) \
-                           / (np.exp(x - a[5] / a[6]) + np.exp((a[5] - x) / a[6]))
+    dimless_omega = (a[0] + a[1] * x) * np.exp((x - a[2]) / a[3]) \
+                                      / (np.exp((x - a[2]) / a[3]) + np.exp((a[2] - x) / a[3]))\
+                    + a[4] * np.exp((x - a[5]) / a[6]) \
+                           / (np.exp((x - a[5]) / a[6]) + np.exp((a[5] - x) / a[6]))
     return np.exp(dimless_omega)
 
 
